@@ -10,7 +10,7 @@ class TestModules(IsolatedAsyncioTestCase):
     async def test_check_dependencies_no_disabled(self):
         check_dependencies()
 
-    @patch.object(modules, "disabled_modules", ["redis"])
+    @patch.object(modules, "disabled_modules", ["database"])
     async def test_check_dependencies_redis_disabled(self):
         self.assertRaises(Exception, check_dependencies)
 
